=============
Django-Twilio
=============


Integrate Twilio into your Django apps with ease.


.. image:: https://badge.fury.io/py/django-twilio.png
    :target: http://badge.fury.io/py/django-twilio

.. image:: https://travis-ci.org/rdegges/django-twilio.png?branch=master
        :target: https://travis-ci.org/rdegges/django-twilio

.. image:: https://pypip.in/d/django-twilio/badge.png
        :target: https://crate.io/packages/django-twilio

Meta
----

* Author: Randall Degges
* Email:  rdegges@gmail.com
* Maintainer: Paul Hallett
* Email: paul@twilio.com
* Status: active development, stable, maintained


Twilio makes it easy to send & receive SMS messages, and create & manage voice calls through software.

Django-twilio makes it easy to use Twilio in your Django projects.

Documentation
-------------

The documentation is hosted at ReadTheDocs. You can check out the docs
here - http://django-twilio.rtfd.org/
